==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/pt_BR.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de Nuvem Federada Inválida",
    "Server to server sharing is not enabled on this server" : "Servidor para compartilhamento de servidor não está ativo neste servidor",
    "Couldn't establish a federated share." : "Não foi possível estabelecer um compartilhamento federado.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Não foi possível estabelecer um compartilhamento federado, talvez a senha esteja incorreta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitação de Compartilhamento Federado enviada, você receberá um convite. Verifique suas notificações.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Não foi possível estabelecer um compartilhamento federado, parece que o servidor a se federar é muito antigo (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Não é permitido enviar compartilhamentos de grupos federados deste servidor.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Falha ao compartilhar %1$s porque este item já está compartilhado com a conta %2$s",
    "Not allowed to create a federated share to the same account" : "Não é permitido criar um compartilhamento federado para a mesma conta",
    "Federated shares require read permissions" : "Os compartilhamentos federados exigem permissões de leitura",
    "File is already shared with %s" : "O arquivo já é compartilhado com %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "O compartilhamento%1$s falhou, não pude encontrar %2$s, talvez o servidor esteja inacessível ou usa um certificado auto-assinado.",
    "Could not find share" : "Não foi possível encontrar o compartilhamento",
    "Federated sharing" : "Compartilhamento federado",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Você recebeu {share} como um compartilhamento remoto do {user} (em nome de {behalf})",
    "You received {share} as a remote share from {user}" : "Você recebeu {share} como um compartilhamento remoto de {user}",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Federated Cloud Sharing" : "Compartilhamento de Nuvem Federada",
    "Sharing" : "Compartilhar",
    "Federated file sharing" : "Compartilhamento federado de arquivos",
    "Provide federated file sharing across servers" : "Fornecer compartilhamento federado entre servidores",
    "Unable to update federated files sharing config" : "Não é possível atualizar a configuração de compartilhamento de arquivos federados",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Ajuste como as pessoas podem compartilhar entre servidores. Isso também inclui compartilhamentos entre pessoas neste servidor, se elas estiverem usando compartilhamento federado.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitir que pessoas neste servidor enviem compartilhamentos para outros servidores (esta opção também permite acesso WebDAV a compartilhamentos públicos)",
    "Allow people on this server to receive shares from other servers" : "Permitir que pessoas neste servidor recebam compartilhamentos de outros servidores",
    "Allow people on this server to send shares to groups on other servers" : "Permitir que pessoas neste servidor enviem compartilhamentos para grupos em outros servidores",
    "Allow people on this server to receive group shares from other servers" : "Permitir que as pessoas neste servidor recebam compartilhamentos de grupo de outros servidores",
    "Search global and public address book for people" : "Pesquise pessoas no catálogo de endereços global e público",
    "Allow people to publish their data to a global and public address book" : "Permitir que as pessoas publiquem seus dados em um catálogo de endereços público e global",
    "Trusted federation" : "Federação confiável",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Aceitar automaticamente compartilhamentos de contas e grupos federados confiáveis por padrão",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Compartilhe comigo por meio do meu ID de nuvem federado #Nextcloud, consulte {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartilhe comigo através do meu ID de Nuvem Federada #Nextcloud",
    "Cloud ID copied to the clipboard" : "Cloud ID copiado para a área de transferência",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Clipboard not available. Please copy the cloud ID manually." : "Área de transferência indisponível. Copie o ID da nuvem manualmente.",
    "Copied!" : "Copiado!",
    "Federated Cloud" : "Nuvem Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Você pode compartilhar com qualquer pessoa que use Nextcloud ou outros servidores compatíveis com o Open Cloud Mesh (OCM)! Basta colocar sua ID de nuvem federada na caixa de diálogo de compartilhamento. Algo como person@cloud.example.com",
    "Your Federated Cloud ID" : "Seu ID de nuvem federada",
    "Share it so your friends can share files with you:" : "Compartilhe para que seus amigos possam compartilhar arquivos com você:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (anteriormente Twitter)",
    "formerly Twitter" : "anteriormente Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Adicione ao seu website",
    "Share with me via Nextcloud" : "Compartilhe comigo via Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar compartilhamento remoto",
    "Remote share" : "Compartilhamento remoto",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Deseja adicionar o compartilhamento remoto {name} de {owner}@{remote}?",
    "Remote share password" : "Senha do compartilhamento remoto",
    "Incoming share could not be processed" : "A participação não pôde ser processada",
    "Clipboard is not available" : "A área de transferência não está disponível",
    "Your Federated Cloud ID:" : "Sua ID de Nuvem Federada:",
    "Twitter" : "Twitter",
    "Diaspora" : "Diáspora"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/pt_BR.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de Nuvem Federada Inválida",
    "Server to server sharing is not enabled on this server" : "Servidor para compartilhamento de servidor não está ativo neste servidor",
    "Couldn't establish a federated share." : "Não foi possível estabelecer um compartilhamento federado.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Não foi possível estabelecer um compartilhamento federado, talvez a senha esteja incorreta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitação de Compartilhamento Federado enviada, você receberá um convite. Verifique suas notificações.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Não foi possível estabelecer um compartilhamento federado, parece que o servidor a se federar é muito antigo (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Não é permitido enviar compartilhamentos de grupos federados deste servidor.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Falha ao compartilhar %1$s porque este item já está compartilhado com a conta %2$s",
    "Not allowed to create a federated share to the same account" : "Não é permitido criar um compartilhamento federado para a mesma conta",
    "Federated shares require read permissions" : "Os compartilhamentos federados exigem permissões de leitura",
    "File is already shared with %s" : "O arquivo já é compartilhado com %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "O compartilhamento%1$s falhou, não pude encontrar %2$s, talvez o servidor esteja inacessível ou usa um certificado auto-assinado.",
    "Could not find share" : "Não foi possível encontrar o compartilhamento",
    "Federated sharing" : "Compartilhamento federado",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Você recebeu {share} como um compartilhamento remoto do {user} (em nome de {behalf})",
    "You received {share} as a remote share from {user}" : "Você recebeu {share} como um compartilhamento remoto de {user}",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Federated Cloud Sharing" : "Compartilhamento de Nuvem Federada",
    "Sharing" : "Compartilhar",
    "Federated file sharing" : "Compartilhamento federado de arquivos",
    "Provide federated file sharing across servers" : "Fornecer compartilhamento federado entre servidores",
    "Confirm data upload to lookup server" : "Confirmar o upload de dados para o servidor de pesquisa",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Quando ativadas, todas as propriedades da conta (por exemplo, endereço de e-mail) com visibilidade de escopo definida como \"publicada\" serão automaticamente sincronizadas e transmitidas para um sistema externo e disponibilizadas em um catálogo de endereços público e global.",
    "Disable upload" : "Desativar upload",
    "Enable data upload" : "Ativar upload de dados",
    "Confirm querying lookup server" : "Confirmar a consulta ao servidor de pesquisa",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Quando ativada, a entrada de pesquisa ao criar compartilhamentos será enviada para um sistema externo que fornece um catálogo de endereços público e global.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Isso é usado para recuperar o ID da nuvem federada para facilitar o compartilhamento federado.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Além disso, os endereços de e-mail dos usuários podem ser enviados para esse sistema a fim de verificá-los.",
    "Disable querying" : "Desativar consulta",
    "Enable querying" : "Ativar consulta",
    "Unable to update federated files sharing config" : "Não é possível atualizar a configuração de compartilhamento de arquivos federados",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Ajuste como as pessoas podem compartilhar entre servidores. Isso também inclui compartilhamentos entre pessoas neste servidor, se elas estiverem usando compartilhamento federado.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitir que pessoas neste servidor enviem compartilhamentos para outros servidores (esta opção também permite acesso WebDAV a compartilhamentos públicos)",
    "Allow people on this server to receive shares from other servers" : "Permitir que pessoas neste servidor recebam compartilhamentos de outros servidores",
    "Allow people on this server to send shares to groups on other servers" : "Permitir que pessoas neste servidor enviem compartilhamentos para grupos em outros servidores",
    "Allow people on this server to receive group shares from other servers" : "Permitir que as pessoas neste servidor recebam compartilhamentos de grupo de outros servidores",
    "The lookup server is only available for global scale." : "O servidor de pesquisa só está disponível para escala global.",
    "Search global and public address book for people" : "Pesquise pessoas no catálogo de endereços global e público",
    "Allow people to publish their data to a global and public address book" : "Permitir que as pessoas publiquem seus dados em um catálogo de endereços público e global",
    "Trusted federation" : "Federação confiável",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Aceitar automaticamente compartilhamentos de contas e grupos federados confiáveis por padrão",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Compartilhe comigo por meio do meu ID de nuvem federado #Nextcloud, consulte {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartilhe comigo através do meu ID de Nuvem Federada #Nextcloud",
    "Cloud ID copied to the clipboard" : "Cloud ID copiado para a área de transferência",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Clipboard not available. Please copy the cloud ID manually." : "Área de transferência indisponível. Copie o ID da nuvem manualmente.",
    "Copied!" : "Copiado!",
    "Federated Cloud" : "Nuvem Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Você pode compartilhar com qualquer pessoa que use Nextcloud ou outros servidores compatíveis com o Open Cloud Mesh (OCM)! Basta colocar sua ID de nuvem federada na caixa de diálogo de compartilhamento. Algo como person@cloud.example.com",
    "Your Federated Cloud ID" : "Seu ID de nuvem federada",
    "Share it so your friends can share files with you:" : "Compartilhe para que seus amigos possam compartilhar arquivos com você:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (anteriormente Twitter)",
    "formerly Twitter" : "anteriormente Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Adicione ao seu website",
    "Share with me via Nextcloud" : "Compartilhe comigo via Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar compartilhamento remoto",
    "Remote share" : "Compartilhamento remoto",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Deseja adicionar o compartilhamento remoto {name} de {owner}@{remote}?",
    "Remote share password" : "Senha do compartilhamento remoto",
    "Incoming share could not be processed" : "O compartilhamento recebido não pôde ser processado",
    "Clipboard is not available" : "A área de transferência não está disponível",
    "Your Federated Cloud ID:" : "Sua ID de Nuvem Federada:",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
